@@ -14,6 +14,8 @@ pub use client::Client;
 
 mod episode;
 use episode::EpisodeLink;
+mod genre;
+pub use genre::Genre;
 mod movie;
 pub use movie::Movie;
 mod show;
