@@ -1,3 +1,4 @@
+use arrayvec::ArrayVec;
 use serde::de::Unexpected;
 use serde::Deserialize;
 use serde::Deserializer;
@@ -6,6 +7,8 @@ use serde_repr::Deserialize_repr;
 use serde_repr::Serialize_repr;
 use smartstring::alias::String;
 
+use crate::genre::Genre;
+
 #[derive(Debug, Deserialize, Serialize)]
 /// Represents a single title in IMDB; a "title" can be a show, an episode of a show, a movie, etc.  See [TitleType] for a list.
 pub struct Title {
@@ -18,7 +21,7 @@ pub struct Title {
 	pub start_year: Option<u16>,
 	pub end_year: Option<u16>,
 	pub runtime_minutes: Option<u16>,
-	pub genres: Vec<String>
+	pub genres: ArrayVec<Genre, 3>
 }
 
 impl From<TitleFromImdb> for Title /* {{{ */ {
@@ -89,8 +92,8 @@ pub(crate) struct TitleFromImdb {
 	pub end_year: Option<u16>,
 	#[serde(deserialize_with = "crate::util::parse_janky_tsv_option")]
 	pub runtime_minutes: Option<u16>,
-	#[serde(with = "serde_with::StringWithSeparator::<serde_with::CommaSeparator>")]
-	pub genres: Vec<String>
+	#[serde(deserialize_with = "crate::genre::deserialize")]
+	pub genres: ArrayVec<Genre, 3>
 }
 
 #[derive(Debug, Eq, PartialEq)]
